==> vscode-java-code-completion-0.18.0.tgz: package/src/vscode/VsCodeJavaCodeCompletionImpl.ts <==
/**
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import * as vscode from "vscode";
import { JavaCodeCompletionAccessor, JavaCodeCompletionApi, JavaCodeCompletionClass } from "../api";
import { JavaCodeCompletionConstants } from "./JavaCodeCompletionConstants";

export class VsCodeJavaCodeCompletionImpl implements JavaCodeCompletionApi {
  getAccessors(fqcn: string, query: string): Promise<JavaCodeCompletionAccessor[]> {
    const command = vscode.commands.executeCommand(
      JavaCodeCompletionConstants.WORKSPACE_COMMAND,
      JavaCodeCompletionConstants.GET_ACCESSORS,
      fqcn,
      query
    );

    const thenable = command.then((res) => <JavaCodeCompletionAccessor[]>res);
    return Promise.resolve(thenable);
  }
  getClasses(query: string): Promise<JavaCodeCompletionClass[]> {
    const command = vscode.commands.executeCommand(
      JavaCodeCompletionConstants.WORKSPACE_COMMAND,
      JavaCodeCompletionConstants.GET_CLASSES,
      query
    );

    const thenable = command.then((res) => <JavaCodeCompletionClass[]>res);
    return Promise.resolve(thenable);
  }

  isLanguageServerAvailable(): Promise<boolean> {
    const command = vscode.commands.executeCommand(
      JavaCodeCompletionConstants.WORKSPACE_COMMAND,
      JavaCodeCompletionConstants.IS_AVAILABLE
    );

    const thenable = command.then((res) => <boolean>res);
    return Promise.resolve(thenable);
  }
}

==> vscode-java-code-completion-0.21.0.tgz: package/src/vscode/VsCodeJavaCodeCompletionImpl.ts <==
/**
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import * as vscode from "vscode";
import { JavaCodeCompletionAccessor, JavaCodeCompletionApi, JavaCodeCompletionClass } from "../api";
import { JavaCodeCompletionConstants } from "./JavaCodeCompletionConstants";

export class VsCodeJavaCodeCompletionImpl implements JavaCodeCompletionApi {
  getAccessors(fqcn: string, query: string): Promise<JavaCodeCompletionAccessor[]> {
    const command = vscode.commands.executeCommand(
      JavaCodeCompletionConstants.WORKSPACE_COMMAND,
      JavaCodeCompletionConstants.GET_ACCESSORS,
      fqcn,
      query
    );

    const thenable = command.then((res) => res as JavaCodeCompletionAccessor[]);
    return Promise.resolve(thenable);
  }
  getClasses(query: string): Promise<JavaCodeCompletionClass[]> {
    const command = vscode.commands.executeCommand(
      JavaCodeCompletionConstants.WORKSPACE_COMMAND,
      JavaCodeCompletionConstants.GET_CLASSES,
      query
    );

    const thenable = command.then((res) => res as JavaCodeCompletionClass[]);
    return Promise.resolve(thenable);
  }

  isLanguageServerAvailable(): Promise<boolean> {
    const command = vscode.commands.executeCommand(
      JavaCodeCompletionConstants.WORKSPACE_COMMAND,
      JavaCodeCompletionConstants.IS_AVAILABLE
    );

    const thenable = command.then((res) => res as boolean);
    return Promise.resolve(thenable);
  }
}
